@@ -1,13 +1,12 @@
 """Implementation of the STOMP protocol in Python.
-
-For documentation, see: http://packages.python.org/stompy/
 """
-VERSION = (0, 1, 7)
+VERSION = (0, 2, 1)
 __version__ = ".".join(map(str, VERSION))
 __author__ = "Benjamin W. Smith"
 __contact__ = "benjaminwarfield@just-another.net"
 __homepage__ = "http://bitbucket.org/benjaminws/python-stomp/"
 __docformat__ = "restructuredtext"
+__long_description__ = open("docs/introduction.rst").read()
 
 
 def is_stable_release():
